/*
   Eclipse Paho MQTT-JS Utility
   by Elliot Williams for Hackaday article, modified by Drew Harwell
   
   28.08.22 - modded to 2 Tasmota Devices by HoerMirAUf (Creationx-Forum)
*/

// Global variables
var client;

// These are configs	
var hostname      = "10.25.152.145";
var port          = "1884";
var clientId      = "HoerMirAuf";
var user          = "sonoff";
var password      = "0000";
var ssl	          = false;

var device1_cmnd  = "cmnd/Demo1/POWER";
var device1_stat  = "stat/Demo1/POWER";
var device2_cmnd  = "cmnd/Demo2/POWER";
var device2_stat  = "stat/Demo2/POWER";

// This is called after the webpage is completely loaded
// It is the main entry point into the JS code
function connect(){
	// Set up the client
	client = new Paho.MQTT.Client(hostname, Number(port), clientId);
	console.info('Connecting to Server: Hostname: ', hostname, '. Port: ', port, '. Client ID: ', clientId);

	// set callback handlers
	client.onConnectionLost = onConnectionLost;
	client.onMessageArrived = onMessageArrived;

	// see client class docs for all the options
	var options = {
		onSuccess: onConnect, // after connected, subscribes
		userName: user,
		password: password,
		onFailure: onFail,    // useful for logging / debugging
    useSSL: ssl
	};
	// connect the client
	client.connect(options);
	console.info('Connecting...');
}


function onConnect(context) {
	console.log("Client Connected");
    document.getElementById('connect_button').innerHTML = "Connected!";
    document.getElementById('connect_button').disabled = true;
    document.getElementById('on_button_1').disabled = false;
    document.getElementById('off_button_1').disabled = false;
    document.getElementById('on_button_2').disabled = false;
    document.getElementById('off_button_2').disabled = false;

  
    // And subscribe to our topics	-- all with the same callback function
	options = {qos:0, onSuccess:function(context){ console.log("subscribed"); } }
	//client.subscribe(device1_cmnd, options); // subscribe sending command optional
	//client.subscribe(device2_cmnd, options); // subscribe	sending command optional
	client.subscribe(device1_stat, options);
	client.subscribe(device2_stat, options);	
}

function onFail(context) {
	console.log("Failed to connect");
}

function onConnectionLost(responseObject) {
	if (responseObject.errorCode !== 0) {
		console.log("Connection Lost: " + responseObject.errorMessage);
		window.alert("Someone else took my websocket!\nRefresh to take it back.");
	}
}

// Here are the two main actions that drive the webpage:
//  handling incoming messages and the toggle button.

// Updates the webpage elements with new data, and 
//  tracks the Power status as well, 
//  in case multiple clients are toggling it.
function onMessageArrived(message) {
  console.log('got message to topic:',message.destinationName, 'message:', message.payloadString);
  
  /*
  
  // Console log for command - topic optional
  
  if (message.destinationName == device1_cmnd){
    console.log('got Device1 message');
  }
  if (message.destinationName == device2_cmnd){
    console.log('got Device2 message');
  }
  
  */
  
  if (message.destinationName == device1_stat){
    console.log('got Device1 message');
    document.getElementById('DEV1').innerHTML = message.payloadString;
    
  }
  if (message.destinationName == device2_stat){
    console.log('got Device2 message');
    document.getElementById('DEV2').innerHTML = message.payloadString;
  }
}

// Provides the button logic that toggles our Device Power on and off

// Device1:
function device1_on(){
  var payload = "1";
  device1_is_on = true;

	// Send messgae
	message = new Paho.MQTT.Message(payload);
	message.destinationName = device1_cmnd;
	message.retained = true;
	client.send(message);
	console.info('sending: ', payload);
}

function device1_off(){
  var payload = "0";
  device1_is_on = false;

	// Send messgae
	message = new Paho.MQTT.Message(payload);
	message.destinationName = device1_cmnd;
	message.retained = true;
	client.send(message);
	console.info('sending: ', payload);
}

// Device2:
function device2_on(){
  var payload = "1";
  device1_is_on = true;

	// Send messgae
	message = new Paho.MQTT.Message(payload);
	message.destinationName = device2_cmnd;
	message.retained = true;
	client.send(message);
	console.info('sending: ', payload);
}

function device2_off(){
  var payload = "0";
  device1_is_on = false;

	// Send messgae
	message = new Paho.MQTT.Message(payload);
	message.destinationName = device2_cmnd;
	message.retained = true;
	client.send(message);
	console.info('sending: ', payload);
}